
library(shiny)
library(cluster)

head( iris )
mydata <- iris[, -5]
head( mydata )
kc <- kmeans( mydata, 3 )

# colores por especies
mycolor <- as.character( factor( iris$Species, 
                                 labels = c(1:3) ) )

palette(c("#E41A1C", "#377EB8", "#4DAF4A", "#984EA3",
          "#FF7F00", "#FFFF33", "#A65628", "#F781BF", "#999999"))

# Define UI for application that draws a histogram
ui <- shinyUI(pageWithSidebar(
    headerPanel('Iris k-means clustering'),
    sidebarPanel(
      #selectInput('xcol', 'X Variable', names(iris)),
      #selectInput('ycol', 'Y Variable', names(iris),
                  #selected=names(iris)[[2]]),
      numericInput('clusters', 'Cluster count', 3,
                   min = 1, max = 9)
    ),
    mainPanel(
      plotOutput('plot1'),
      plotOutput('plot2')
    )
  ))


clusplot( mydata, kc$cluster, color = TRUE, 
          shade = TRUE, labels = 4, lines = 1, col.p = kc$cluster )

# Define server logic required to draw a histogram
server <- shinyServer(function(input, output, session) {
  
  # Combine the selected variables into a new data frame
  #selectedData <- reactive({
  #  iris[, c(input$xcol, input$ycol)]
  #})
  
  clusters <- reactive({
    pam(iris[,1:4], input$clusters)
  })
  silu<- reactive({
    silhouette(clusters())
  })
  output$plot1 <- renderPlot({
    #par(mar = c(5.1, 4.1, 0, 1))
    
    clusplot(iris[,1:4], clusters()$cluster,
         col.p = clusters()$cluster, shade=TRUE, 
         labels = 4, lines =1
         )
    
  }, height = 'auto', width = 'auto' )
  output$plot2 <- renderPlot({
    
    plot(silu())
  }, height = 'auto', width = 'auto')
})

# Run the application 
shinyApp(ui = ui, server = server)

